<!---  
/**
 * Convert cardinal numbers to ordinal number strings in Brazilian Portuguese. Accept 999.999 as maximum number.
 * 
 * @param numero  Cardinal number to convert. 
 * @return The ordinal number as string.
 * @author Fabio Terracini (fabioterracini@gmail.com) 
 * @version 1.0, February 18, 2005 
 */
--->

<cffunction name="cardinalParaOrdinal" output="No" returntype="string" description="Passado um valor numrico retorna o nmero cardinal escrito por extenso. Aceita o valor mximo de 999.999">
	<cfargument name="numero" required="Yes" type="numeric">

	<cfset var aUnidade=ListToArray("primeiro,segundo,terceiro,quarto,quinto,sexto,stimo,oitavo,nono")>
	<cfset var aDezena=ListToArray("dcimo,vigsimo,trigsimo,quadrigsimo,quinquagsimo,sexagsimo,septuagsimo,octoagsimo,nonagsimo")>
	<cfset var aCentena=ListToArray("centsimo,ducentsimo,trecentsimo,quadringentsimo,qingentsimo,sexcentsimo,septingentsimo,octingentsimo,noningentsimo")>
	<cfset var numeroParseado=LSParseNumber(arguments.numero)>
	<cfset var numeroFormatado=NumberFormat(numeroParseado,"0,0")>
	<cfset var aDigitos=ArrayNew(1)>
	<cfset var numeroOrdinalExtenso="">
	<cfset var k="">
	<cfset var numeroAteCent=NumberFormat(ListLast(numeroFormatado),"000")>

	<!--- Validao para nmero mximo --->
	<cfif NOT isValid("range", numeroParseado, 1, 999999)>
		<cfthrow message="A UDF cardinalParaOrdinal() aceita 999.999 como valor mximo e 1 como valor mnimo.">
	</cfif>
	
	<!--- numero maior do que um mil; milsimo --->
	<cfif numeroParseado GTE 1000>
		<cfset milhares=ListFirst(numeroFormatado)>
		<cfset numeroOrdinalExtenso = numeroOrdinalExtenso & cardinalParaOrdinal(milhares) & " milsimo">		
	</cfif>
	
	<!--- numeros at 999 --->
	<cfset aDigitos[1]=Left(numeroAteCent,1)>
	<cfset aDigitos[2]=Mid(numeroAteCent,2,1)>
	<cfset aDigitos[3]=Right(numeroAteCent,1)>
	
	<cfloop from="1" to="3" index="k" step="1">
		<cfset numeroDaVez=aDigitos[k]>
		
		<cfif numeroDaVez><!--- maior do que zero --->
		
			<cfswitch expression="#k#">
				<cfcase value="1">
					<cfset numeroOrdinalExtenso = numeroOrdinalExtenso & " " & aCentena[numeroDaVez]>
				</cfcase>
				<cfcase value="2">
					<cfset numeroOrdinalExtenso = numeroOrdinalExtenso & " " & aDezena[numeroDaVez]>
				</cfcase>
				<cfcase value="3">
					<cfset numeroOrdinalExtenso = numeroOrdinalExtenso & " " & aUnidade[numeroDaVez]>
				</cfcase>
			</cfswitch>
			
		</cfif>
		
	</cfloop>
	
	<cfreturn numeroOrdinalExtenso>

</cffunction>

<cfoutput>#cardinalParaOrdinal("987.654")#</cfoutput>